package com.chinaitop.agile.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.model.DataKcglFcbgzDefault;
import com.chinaitop.agile.model.DataKcglFcbgzDefaultExample;
import com.chinaitop.agile.model.DataKcglFcbgzDefaultExample.Criteria;
import com.chinaitop.agile.service.DataKcglFcbgzDefaultService;
import com.chinaitop.agile.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/agile/fcbgzController")
@Api(value= "FcbgzController", description = "分仓保管账控制类")
public class FcbgzController {

	@Resource
	private DataKcglFcbgzDefaultService fcbgzService;

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="分仓保管账记录查询", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name="pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name="pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name="orgId", value = "单位ID", paramType = "query"),
		@ApiImplicitParam(name="houseId", value="仓房ID ", paramType="query"),
		@ApiImplicitParam(name="warehouseId", value="货位ID", paramType="query"),
		@ApiImplicitParam(name="direction", value="数据来源 (1入库,-1出库)", paramType="query"),
		@ApiImplicitParam(name="modifyData", value="录入时间", paramType="query")
	})
	public PageInfo<DataKcglFcbgzDefault> getList(Integer pageNum, Integer pageSize, 
			Integer orgId, String houseId, String warehouseId, Integer direction, String modifyData) {

		DataKcglFcbgzDefaultExample example = new DataKcglFcbgzDefaultExample();
		Criteria criteria = example.createCriteria();
		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}
		/* 单位 */
		if (null != orgId) {
			criteria.andUnitidEqualTo(orgId.toString());
		}
		/* 仓房 */
		if (null != houseId) {
			criteria.andChEqualTo(houseId);
		}
		/* 货位 */
		if (null != warehouseId) {
			criteria.andHwhEqualTo(warehouseId);
		}
		/* 数据方向 (1入库,-1出库)*/
		if (null != direction) {
			criteria.andDirectionEqualTo(direction);
		}
		if (null != modifyData) {
			Date date = ParameterUtil.string2datetime(modifyData);
			criteria.andModifydateGreaterThanOrEqualTo(date);
		}
		example.setOrderByClause(" ModifyDate DESC");
		List<DataKcglFcbgzDefault> list = null;
		try {
			list = fcbgzService.findByList(example);
		} catch (Exception e) {
			e.printStackTrace();
		}
		PageInfo<DataKcglFcbgzDefault> pageInfo = new PageInfo<DataKcglFcbgzDefault>(list);

		return pageInfo;
	}

	@RequestMapping(value="/queryFcbgzData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="分仓保管账记录查询", notes = "分仓保管账记录查询")
	@ApiImplicitParams({
		@ApiImplicitParam(name="datas", value="条件", paramType="query")
	})
	public List<DataKcglFcbgzDefault> queryFcbgzData(String datas) {
		
		ObjectMapper mapper = new ObjectMapper();
		List<DataKcglFcbgzDefault> result_list = new ArrayList<DataKcglFcbgzDefault>();

		DataKcglFcbgzDefault fcbgz = null;
		List<DataKcglFcbgzDefault> list = null;
		try {
			List<DataKcglFcbgzDefault> param_List = mapper.readValue(datas, new TypeReference<List<DataKcglFcbgzDefault>>(){});
			if (null != param_List && param_List.size() > 0) {
				for (DataKcglFcbgzDefault obj : param_List) {
					fcbgz = obj;
					DataKcglFcbgzDefaultExample example = new DataKcglFcbgzDefaultExample();
					Criteria criteria = example.createCriteria();
					
					/* 单位 */
					if (null != fcbgz.getUnitid()) {
						criteria.andUnitidEqualTo(fcbgz.getUnitid());
					}
					
					/* 货位 */
					if (null != fcbgz.getHwh()) {
						criteria.andHwhEqualTo(fcbgz.getHwh());
					}
					
					/* 录入时间 */
					if (null != fcbgz.getModifydate()) {
						criteria.andModifydateGreaterThanOrEqualTo(fcbgz.getModifydate());
					}
					example.setOrderByClause(" ModifyDate ASC");
					list = fcbgzService.findByList(example);
					if (null != list && list.size() > 0) {
						for (DataKcglFcbgzDefault obj1 : list) {
							obj1.setOlddataid(ParameterUtil.datetime2string(obj1.getModifydate()));
							result_list.add(obj1);
						}
					}
				}
			}
		} catch (Exception e1) {
			e1.printStackTrace();
		}

		return result_list;
	}
	
	@RequestMapping(value="/findByIdFcbgzData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询一条分仓保管账记录", notes = "查询一条分仓保管账记录")
	@ApiImplicitParams({
		@ApiImplicitParam(name="id", value="数据ID", paramType="query")
	})
	public Map<String, Object> findByIdFcbgzData(String id) {
		
		Map<String, Object> result_map = new HashMap<String, Object>();

		DataKcglFcbgzDefault fcbgz = null;
		try {
			if (!"".equals(ObjectUtils.toString(id, ""))) {
				fcbgz = fcbgzService.findByIdFcbgzData(id);
			} else {
				fcbgz = new DataKcglFcbgzDefault();
			}
			result_map.put("fcbgz", fcbgz);
		} catch (Exception e1) {
			e1.printStackTrace();
		}

		return result_map;
	}
}
