package com.chinaitop.agile.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.service.DataKcglFcbgzDefaultService;
import com.chinaitop.agile.service.KeepAccountService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/keepAccount")
@Api(value= "KeepAccountController", description = "保管账控制类")
public class KeepAccountController {
	
	@Resource
	private KeepAccountService keepAccountService;
	@Resource
	private DataKcglFcbgzDefaultService fcbgzService;

	/**
	 * 保管明细账列表
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param ch 仓号ID
	 * @param hwh 货位号ID
	 * @param lspz 品种
	 * @param lsxz 货物性质
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/list", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="保管明细账列表", notes = "保管明细账列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
		@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
		@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
		@ApiImplicitParam(name="endDate", value="结束时间", paramType="query")
	})
	public PageInfo<Map<String, Object>> list(HttpServletRequest request, Integer pageNum, Integer pageSize, 
			String ch, String hwh, Integer lspz, Integer lsxz, String startDate, String endDate) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (ch != null && !"".equals(ch)) {
			map.put("ch", ch);
		}
		if (hwh != null && !"".equals(hwh)) {
			map.put("hwh", hwh);
		}
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (startDate != null && !"".equals(startDate)) {
			map.put("startDate", startDate+" 00:00:00");
		}
		if (endDate != null && !"".equals(endDate)) {
			map.put("endDate", endDate+" 23:59:59");
		}
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		if (null != orgId && !"".equals(orgId)) {
			map.put("orgId", orgId);
		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<Map<String, Object>> list = keepAccountService.selectHouseKeepAccountData(map);
		PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
		return pageInfo;
	}

	/**
	 * 分仓保管列表，按天统计
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param ch 仓号ID
	 * @param hwh 货位号ID
	 * @param lspz 品种
	 * @param lsxz 货物性质
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/houseKeepAccountList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="分仓保管列表，按天统计", notes = "分仓保管列表，按天统计，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
		@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
		@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
		@ApiImplicitParam(name="endDate", value="结束时间", paramType="query")
	})
	public PageInfo<Map<String, Object>> houseKeepAccountList(HttpServletRequest request, Integer pageNum, Integer pageSize, 
			String ch, String hwh, Integer lspz, Integer lsxz, String startDate, String endDate) {

		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		PageInfo<Map<String, Object>> pageInfo = null;
		try {
			pageInfo = keepAccountService.queryTotalByExample(pageNum, pageSize, 
					ch, hwh, lspz, lsxz, startDate, endDate, orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}

	/**
	 * 查询出入库数据
	 * @param queryTyep 查询类型
	 * @param ch 仓号ID
	 * @param hwh 货位号ID
	 * @param jjdh 检斤单号
	 * @return
	 */
	@RequestMapping(value="/getCRKData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询出入库数据", notes = "查询出入库数据")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "queryTyep", value = "查询类型", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name = "jjdh", value = "检斤单号", paramType = "query")
	})
	public Map<String, Object> getCRKData(String queryTyep, String ch, String hwh, String jjdh) {
		return keepAccountService.getOnDayData(queryTyep, ch, hwh, jjdh);
	}

	/**
	 * 查询保管明细账数量合计
	 * @param orgId 组织机构id
	 * @param ch 仓号ID
	 * @param hwh 货位号ID
	 * @param lspz 品种
	 * @param lsxz 货物性质
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/getCountQYzl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="保管明细账数量合计", notes = "查询保管明细账数量合计")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
			@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
			@ApiImplicitParam(name = "hwh", value = "货位号ID", paramType = "query"),
			@ApiImplicitParam(name = "lspz", value = "品种", paramType = "query"),
			@ApiImplicitParam(name = "lsxz", value = "货物性质", paramType = "query"),
			@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
			@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query")
	})
	public Map<String, Object> getCountQYzl(Integer orgId, String ch, String hwh, Integer lspz, Integer lsxz, String startDate, String endDate) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (ch != null && !"".equals(ch)) {
			map.put("ch", ch);
		}
		if (hwh != null && !"".equals(hwh)) {
			map.put("hwh", hwh);
		}
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (startDate != null && !"".equals(startDate)) {
			map.put("startDate", startDate+" 00:00:00");
		}
		if (endDate != null && !"".equals(endDate)) {
			map.put("endDate", endDate+" 23:59:59");
		}

		if (null != orgId && !"".equals(orgId)) {
			map.put("orgId", orgId);
		}
		Map<String, Object> mapSumNumber = keepAccountService.getCountQYzl(map);
		return mapSumNumber;
	}
}
