package com.chinaitop.agile.service.impl;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;

import com.chinaitop.agile.mapper.BasicEnumMapper;
import com.chinaitop.agile.model.*;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.agile.feign.service.BasicEnumFeignService;
import com.chinaitop.agile.mapper.DataKcglFcbgzDefaultMapper;
import com.chinaitop.agile.mapper.DataKcglKcswDefaultMapper;
import com.chinaitop.agile.mapper.DataKcglXckcDefaultMapper;
import com.chinaitop.agile.model.DataKcglKcswDefaultExample.Criteria;
import com.chinaitop.agile.service.KcswService;
import com.chinaitop.agile.utils.ParameterUtil;

@Service
public class KcswServiceImpl implements KcswService{

	@Resource
	private DataKcglKcswDefaultMapper dataKcglKcswDefaultMapper;
	@Resource
	private DataKcglXckcDefaultMapper dataKcglXckcDefaultMapper;
	@Resource
	private DataKcglFcbgzDefaultMapper dataKcglFcbgzDefaultMapper;
	@Resource
	private BasicEnumFeignService basicEnumFeignService;
	@Resource
	private BasicEnumMapper enumMapper;

	public Map<String, Object> queryByExample(Integer orgId) {
		/* 返回数据对象 */
		Map<String, Object> modelMap = new HashMap<String, Object>();
		
		/* 当前年份  */
		int this_year = Integer.parseInt(ParameterUtil.getSysDateYear());

		/* 封装年份  */
		String []year_num = new String[5];
		year_num[0] = this_year - 4 + "";
		year_num[1] = this_year - 3 + "";
		year_num[2] = this_year - 2 + "";
		year_num[3] = this_year - 1 + "";
		year_num[4] = this_year + "";
		modelMap.put("years", year_num);

		/* 查询库存数量表数据  */
		DataKcglKcswDefaultExample example = new DataKcglKcswDefaultExample();
		Criteria criteria = example.createCriteria();
		criteria.andUnitidEqualTo(orgId+"");
		List<DataKcglKcswDefault> list = dataKcglKcswDefaultMapper.selectByExample(example);

		String pz = "";
		String year = "0";
		DecimalFormat obj = new DecimalFormat(".0000");  // 保留4位小数
		String sumCkslFormat = "";
		BigDecimal sumCksls = null;
		
		double []_xiaomai = new double[5];
		double []_yumi = new double[5];
		double []_daogu = new double[5];
		double []_dadou = new double[5];
		for (int i = 0; i < year_num.length; i++) {
			double sumXiaomaikcsl = 0d; //小麦
			double sumYumikcsl = 0d; //玉米
			double sumDadoukcsl = 0d; //大豆
			double sumDaogukcsl = 0d; //稻谷
			if (null != list && list.size() > 0) {
				for (DataKcglKcswDefault kcsw_obj : list) {
					DataKcglFcbgzDefaultExample fcbgz_example = new DataKcglFcbgzDefaultExample();
					DataKcglFcbgzDefaultExample.Criteria fcbgz_criteria = fcbgz_example.createCriteria();
					fcbgz_criteria.andUnitidEqualTo(kcsw_obj.getUnitid());
					fcbgz_criteria.andChEqualTo(kcsw_obj.getCh());
					fcbgz_criteria.andHwhEqualTo(kcsw_obj.getHwh());
					fcbgz_criteria.andSrslGreaterThan(0d);//收入数量大于0
					fcbgz_example.setOrderByClause(" rq DESC");
					//给生产年份赋值
					List<DataKcglFcbgzDefault> fcbgz_list = dataKcglFcbgzDefaultMapper.selectByExample(fcbgz_example);
					Integer scnf = 0;
					if (null != fcbgz_list && fcbgz_list.size() > 0) {
						scnf = Integer.parseInt(ObjectUtils.toString(fcbgz_list.get(0).getScnf(), "0"));
					}
					pz = kcsw_obj.getPz();
					if (null == scnf || "".equals(scnf)) {
						scnf = 0;
					}
					/* 获取年份的字典值 */
					BasicEnum strResult = enumMapper.selectByPrimaryKey(scnf);
					if (null != strResult && !"".equals(strResult)) {
						year =strResult.getEnumname();

					} else {
						year = "0";
					}
					if (year.equals(year_num[i]) && "3164".equals(pz)) {//这个年份小麦的数据
						sumXiaomaikcsl = sumXiaomaikcsl + kcsw_obj.getKcsl();
					} else if (year.equals(year_num[i]) && "3165".equals(pz)) {//这个年份玉米的数据
						sumYumikcsl = sumYumikcsl + kcsw_obj.getKcsl();
					} else if (year.equals(year_num[i]) && "3166".equals(pz)) {//这个年份稻谷的数据
						sumDaogukcsl = sumDaogukcsl + kcsw_obj.getKcsl();
					} else if (year.equals(year_num[i]) && "2777".equals(pz)) {//这个年份大豆的数据
						sumDadoukcsl = sumDadoukcsl + kcsw_obj.getKcsl();
					}
				}
			}
			//处理小麦
			sumCkslFormat = obj.format(sumXiaomaikcsl/1000);
			sumCksls = new BigDecimal(sumCkslFormat);
			_xiaomai[i] = Double.parseDouble(sumCksls+"");

			//处理玉米
			sumCkslFormat = obj.format(sumYumikcsl/1000);
			sumCksls = new BigDecimal(sumCkslFormat);
			_yumi[i] = Double.parseDouble(sumCksls+"");

			//处理稻谷
			sumCkslFormat = obj.format(sumDaogukcsl/1000);
			sumCksls = new BigDecimal(sumCkslFormat);
			_daogu[i] = Double.parseDouble(sumCksls+"");

			//处理大豆
			sumCkslFormat = obj.format(sumDadoukcsl/1000);
			sumCksls = new BigDecimal(sumCkslFormat);
			_dadou[i] = Double.parseDouble(sumCksls+"");
		}

		modelMap.put("xiaomai", _xiaomai);
		modelMap.put("yumi", _yumi);
		modelMap.put("daogu", _daogu);
		modelMap.put("dadou", _dadou);

		return modelMap;
	}

	public Map<String, Object> queryByDj(Integer orgId) {
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		List<DataKcswScedule> countByDj = dataKcglKcswDefaultMapper.countByDj(map);
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StringBuilder yi=new StringBuilder();
		StringBuilder er=new StringBuilder();
		StringBuilder san=new StringBuilder();
		for (DataKcswScedule dataKcswScedule : countByDj) {
			String djmc = dataKcswScedule.getDjmc();
			if("3271".equals(djmc)){
				yi.append(dataKcswScedule.getSumCksl());
			}else if (djmc.equals("3272")) {
				er.append(dataKcswScedule.getSumCksl());
			}else if (djmc.equals("3273")) {
				san.append(dataKcswScedule.getSumCksl());
			}
		}
		modelMap.put("yi", yi);
		modelMap.put("er", er);
		modelMap.put("san", san);
		
		return modelMap;
	}

	public String queryByBl(Integer effectiveCapacity, Map<String, Object> map) {
		String sumCksl = dataKcglKcswDefaultMapper.countByBl(map);
		System.out.println("库容是："+effectiveCapacity+"-----库存量是："+sumCksl);
		if(sumCksl!=null){
			BigDecimal sumCksls = new BigDecimal(sumCksl.toString());
			BigDecimal effectiveCapacitys = new BigDecimal(effectiveCapacity.toString());
			BigDecimal ss = new BigDecimal(1000);
			BigDecimal sumCksls2 = sumCksls.divide(ss);
			BigDecimal divide = sumCksls2.divide(effectiveCapacitys, 4, RoundingMode.CEILING);
			BigDecimal s = new BigDecimal(100);
			BigDecimal multiply = divide.multiply(s);
			float a = multiply.floatValue();
			String string = "";
			if (a > 100) {
				string = "100";
			} else {
				string = multiply.toString();
			}
//			double sumCkslDouble = Double.parseDouble(string);
//			DecimalFormat obj = new DecimalFormat(".00");  // 保留2位小数
//			String format = obj.format(sumCkslDouble);
			return string;
		}
		return "0";
	}

	@Override
	public List<DataKcglKcswDefault> findCondition(DataKcglKcswDefaultExample example) {
		return dataKcglKcswDefaultMapper.selectByExample(example);
	}

	@Override
	public List<DataKcglKcswDefault> findLiangQuanCondition(Map<String, Object> mapExample) {
		return dataKcglKcswDefaultMapper.findLiangQuanCondition(mapExample);
	}

	@Override
	public List<DataKcglKcswDefault> findLiangQuankcsl(Map<String, Object> mapExample) {
		return dataKcglKcswDefaultMapper.findLiangQuankcsl(mapExample);
	}

	@Override
	public List<DataKcglKcswDefault> getEmptyPolice(DataKcglKcswDefaultExample example) {
		return dataKcglKcswDefaultMapper.getEmptyPolice(example);
	}
	
	
	//获取仓房货位
	@Override
	public List<DataKcglKcswDefault> getHouseOrWareList(Map<String, Object> modelMap) {
		// TODO Auto-generated method stub
		return dataKcglKcswDefaultMapper.getHouseOrWareList(modelMap);
	}

	@Override
	public List<Map<String, Object>> selectCountByPz() {
		return dataKcglKcswDefaultMapper.countByPz();
	}

	@Override
	public List<Map<String, Object>> selectCountByXz() {
		return dataKcglKcswDefaultMapper.countByXz();
	}

	@Override
	public List<Map<String, Object>> selectCountByYear() {
		return dataKcglKcswDefaultMapper.countByYear();
	}

	@Override
	public List<Map<String, Object>> selectCountByCity() {
		return dataKcglKcswDefaultMapper.countByCity();
	}

	/*@Override
	public List<StorageQualitycheck> getCountBych(Map<String, Object> modelMap) {
		// TODO Auto-generated method stub
		return dataKcglKcswDefaultMapper.getCountBych(modelMap);
	}
*/
	@Override
	public List<DataKcglKcswDefault> getMassageBych(Map<String, Object> modelMap) {
		// TODO Auto-generated method stub
		return dataKcglKcswDefaultMapper.getMassageBych(modelMap);
	}

	@Override
	public List<DataKcglKcswDefault> queryLKNewData(Map<String, Object> map) {
		List<DataKcglKcswDefault> selectByExample = dataKcglKcswDefaultMapper.queryLKNewData(map);
		return selectByExample;
	}

	@Override
	public void updateKc(String userInfo, String profitlossSheet) {

		if (null == userInfo || null == profitlossSheet) {
			return;
		}
		JSONObject user = JSONObject.parseObject(userInfo);
		JSONObject sheet = JSONObject.parseObject(profitlossSheet);

		/* 删除对应仓房的库存实物数据 */
		DataKcglKcswDefaultExample example = new DataKcglKcswDefaultExample();
		Criteria criteria = example.createCriteria();
		criteria.andChEqualTo(sheet.get("houseId").toString());
		criteria.andHwhEqualTo(sheet.get("warehouseId").toString());
		DataKcglKcswDefault kcsw = dataKcglKcswDefaultMapper.selectByExample(example).get(0);
		dataKcglKcswDefaultMapper.deleteByPrimaryKey(kcsw.getDataid());

		/* 插入形成库存数据 */
		DataKcglXckcDefault dataKcglXckcDefault = new DataKcglXckcDefault();
		String uuid = UUID.randomUUID().toString().replace("-", "");
		dataKcglXckcDefault.setDataid(uuid);
		dataKcglXckcDefault.setUnitid(user.get("orgId").toString());
		dataKcglXckcDefault.setPeriodid(kcsw.getPeriodid());
		Byte roundid = 0;
		dataKcglXckcDefault.setRoundid(roundid);
		dataKcglXckcDefault.setModifydate(new Date());
		dataKcglXckcDefault.setBuilder(user.get("username").toString());
		dataKcglXckcDefault.setMxpz(sheet.get("grainKind").toString());
		dataKcglXckcDefault.setLkmc(user.get("orgName")==null?"":user.get("orgName").toString());
		dataKcglXckcDefault.setPz(sheet.get("grainKind").toString());
		dataKcglXckcDefault.setSjcf(sheet.get("houseId").toString());
		dataKcglXckcDefault.setDj(sheet.get("grainGrade").toString());
		dataKcglXckcDefault.setSjhw(sheet.get("warehouseId").toString());
		dataKcglXckcDefault.setScnf(sheet.get("productionYear").toString());
		dataKcglXckcDefault.setCazylx("溢出");
		double xzklhjz = Double.valueOf(sheet.get("incomeTonnage").toString());
		dataKcglXckcDefault.setXxklhjz(xzklhjz);
		dataKcglXckcDefault.setTzdh(0);
		dataKcglXckcDefault.setShoworder(0);
		dataKcglXckcDefault.setBizno("0");

		int count = dataKcglXckcDefaultMapper.insertSelective(dataKcglXckcDefault);

		if (count > 0) {
			/* 插入分仓保管账数据  */
			DataKcglFcbgzDefault dataKcglFcbgzDefault = new DataKcglFcbgzDefault();
			dataKcglFcbgzDefault.setDataid(uuid);
			dataKcglFcbgzDefault.setUnitid(user.get("orgId").toString());
			dataKcglFcbgzDefault.setRoundid(roundid);
			dataKcglFcbgzDefault.setPeriodid(kcsw.getPeriodid());
			dataKcglFcbgzDefault.setModifydate(new Date());
			dataKcglFcbgzDefault.setBuilder(dataKcglXckcDefault.getBuilder());
			dataKcglFcbgzDefault.setLkmc(dataKcglXckcDefault.getLkmc());
			dataKcglFcbgzDefault.setCh(kcsw.getCh());
			dataKcglFcbgzDefault.setHwh(kcsw.getHwh());
			dataKcglFcbgzDefault.setPz(dataKcglXckcDefault.getPz());
			dataKcglFcbgzDefault.setZcsl(xzklhjz);
			dataKcglFcbgzDefault.setKcsl(0d);
			dataKcglFcbgzDefault.setJzr(user.get("username").toString());
			dataKcglFcbgzDefault.setMxpz(dataKcglXckcDefault.getMxpz());
			dataKcglFcbgzDefault.setDj(dataKcglXckcDefault.getDj());
			dataKcglFcbgzDefault.setCjsj(new Date());
			dataKcglFcbgzDefault.setDirection(1);
			dataKcglFcbgzDefault.setScnf(dataKcglXckcDefault.getScnf());

			dataKcglFcbgzDefaultMapper.insertSelective(dataKcglFcbgzDefault);
		}
	}

	/**
	 * 根据orgId查询库存数量
	 */
	@Override
	public List<DataKcglKcswDefault> queryKcData(Integer orgId, String houseId, String warehouseId) {
		// TODO Auto-generated method stub
		DataKcglKcswDefaultExample example = new DataKcglKcswDefaultExample();
        Criteria createCriteria = example.createCriteria();
        if(warehouseId!=null && warehouseId.equals("0")){//油料(仓房号和货位号是一样的)(品种是油的，7031,7036)
        	if(orgId!=null){
        		createCriteria.andUnitidEqualTo(String.valueOf(orgId));
        	}
        	if(houseId!=null){
        		createCriteria.andChEqualTo(houseId);
        	}
        	createCriteria.andPzBetween("7031", "7036");
        }else{//粮食的
        	if(orgId!=null){
        		createCriteria.andUnitidEqualTo(String.valueOf(orgId));
        	}
        	if(houseId!=null){
        		createCriteria.andChEqualTo(houseId);
        	}
        	if(warehouseId!=null){
        		createCriteria.andHwhEqualTo(warehouseId);
        	}
        }
        example.setOrderByClause("ch asc");
		return dataKcglKcswDefaultMapper.selectByExample(example);
	}

	@Override
	public String countByBl(Map<String, Object> map) {
		return dataKcglKcswDefaultMapper.countByBl(map);
	}

	@Override
	public List<DataKcglKcswDefault> get_thenTwoYear_List(Map<String, Object> map) {
		List<DataKcglKcswDefault> list = dataKcglKcswDefaultMapper.get_thenTwoYear_List(map);
		return list;
	}

	@Override
	public List<DataKcglKcswDefault> getDateByChHwh(Map<String, Object> modelMap) {
		// TODO Auto-generated method stub
		return dataKcglKcswDefaultMapper.getDateByChHwh(modelMap);
	}

	@Override
	public List<DataKcglKcswDefault> findListOrRcsj(DataKcglKcswDefault kcsw) {
		List<DataKcglKcswDefault> list =null;
		if (kcsw.getCh().length()>10){
			list = dataKcglKcswDefaultMapper.findListOrRcsjtank(kcsw);
		}else {
			list = dataKcglKcswDefaultMapper.findListOrRcsj(kcsw);
		}
		return list;
	}
}
